==> haskell-brick-0.47.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.47.1
id: brick-0.47.1-G6HmquiVgYUGktNH9Ehzao
key: brick-0.47.1-G6HmquiVgYUGktNH9Ehzao
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: c8985bfabf9db459d5a20d68c709f22e
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.47.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.47.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/brick-0.47.1
hs-libraries: HSbrick-0.47.1-G6HmquiVgYUGktNH9Ehzao
depends:
    base-4.12.0.0 config-ini-0.2.4.0-1Uv5JM3SvSW4TsxKNw0gAr
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    data-clist-0.1.2.3-GvnLLpQY880LhEdRcKP98I deepseq-1.4.4.0
    directory-1.3.3.0 dlist-0.8.0.6-9UgEeUYmxlQ4pf6zqiW0es
    filepath-1.4.2.1 microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR
    microlens-mtl-0.2.0.1-YTFbHudevv9mEzCYQBIKT
    microlens-th-0.4.3.2-LqA2iMwHon3GVoHwu983SC stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    text-zipper-0.10.1-JkqGgN6zbRU5SddSjNsQLm transformers-0.5.6.2
    unix-2.7.2.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vty-5.25.1-7HOoryGNetBKpCZF0x8Xt0
    word-wrap-0.4.1-JX40dmfHIiLFjmOjTDVu4T
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brick-0.47.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.47.1
id: brick-0.47.1-FKU2CHTF8kiKfoq50uOt37
key: brick-0.47.1-FKU2CHTF8kiKfoq50uOt37
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: 07249776d3a2f342345930801764e437
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.47.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.47.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/brick-0.47.1
hs-libraries: HSbrick-0.47.1-FKU2CHTF8kiKfoq50uOt37
depends:
    base-4.12.0.0 config-ini-0.2.4.0-1Uv5JM3SvSW4TsxKNw0gAr
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    data-clist-0.1.2.3-GvnLLpQY880LhEdRcKP98I deepseq-1.4.4.0
    directory-1.3.3.0 dlist-0.8.0.7-1GKAIxsjCWl8wyFooV703D
    filepath-1.4.2.1 microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR
    microlens-mtl-0.2.0.1-YTFbHudevv9mEzCYQBIKT
    microlens-th-0.4.3.2-LqA2iMwHon3GVoHwu983SC stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    text-zipper-0.10.1-JkqGgN6zbRU5SddSjNsQLm transformers-0.5.6.2
    unix-2.7.2.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vty-5.25.1-7HOoryGNetBKpCZF0x8Xt0
    word-wrap-0.4.1-JX40dmfHIiLFjmOjTDVu4T
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
